import { __assign, __awaiter, __generator } from "tslib";
import * as React from "react";
import { render } from "@testing-library/react";
import "@testing-library/jest-dom/extend-expect";
import { ViewPort } from "../ViewPort";
import { drag } from "./TestUtils";
import { ResizeType } from "../../core-types";
import { Positioned } from "../Positioned";
export var mutateComponent = function (component, newProps) {
    return React.cloneElement(component, newProps);
};
export function hasProps(name, component, props) {
    props.forEach(function (prop) {
        expect(prop in component.propTypes, "".concat(prop, " missing")).toBe(true);
    });
}
export var fixUp = function (sut) {
    // This is annoying. A bug in JSDOM means that getComputedStyle() on test elements does
    // not correctly return the applied styles when a dynamically added style tag is added to
    // the document.head. It doesn't happen in all cases. Quick fix for now is take the style
    // from the doc head and apply directly to the test element
    // Existing issue raised on JSDOM repo - https://github.com/jsdom/jsdom/issues/2986
    var test = document.documentElement.querySelector("#style_".concat(sut.id));
    var style = test.innerHTML
        .replace("#".concat(sut.id, " { "), "")
        .split("#")[0]
        .replace(" }", "");
    sut.setAttribute("style", style);
    return sut;
};
export function commonPropTypesTest(name, component) {
    var _this = this;
    test("".concat(name, " has correct common prop types"), function () { return __awaiter(_this, void 0, void 0, function () {
        return __generator(this, function (_a) {
            hasProps(name, component, [
                "as",
                "centerContent",
                "className",
                "id",
                "scrollable",
                "trackSize",
                "zIndex",
                "allowOverflow",
                "onClick",
                "onDoubleClick",
                "onMouseDown",
                "onMouseEnter",
                "onMouseLeave",
                "onMouseMove",
                "onTouchStart",
                "onTouchMove",
                "onTouchEnd",
            ]);
            return [2 /*return*/];
        });
    }); });
}
export function resizablePropTypesTest(name, component) {
    var _this = this;
    commonPropTypesTest(name, component);
    test("".concat(name, " has correct resizable prop types"), function () { return __awaiter(_this, void 0, void 0, function () {
        return __generator(this, function (_a) {
            hasProps(name, component, [
                "size",
                "handleSize",
                "touchHandleSize",
                "handlePlacement",
                "handleRender",
                "minimumSize",
                "maximumSize",
                "onResizeStart",
                "onResizeEnd",
            ]);
            return [2 /*return*/];
        });
    }); });
}
export function anchorPropTypesTest(name, component) {
    var _this = this;
    resizablePropTypesTest(name, component);
    test("".concat(name, " has correct anchor prop types"), function () { return __awaiter(_this, void 0, void 0, function () {
        return __generator(this, function (_a) {
            hasProps(name, component, ["resizable"]);
            return [2 /*return*/];
        });
    }); });
}
export var commonPropsTests = function (name, component, expectedStyle) {
    test("".concat(name, " default has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test" }))).container;
            sut = container.querySelector("#test");
            style = window.getComputedStyle(sut);
            expect(style.display).toBe("block");
            expect(sut.nodeName).toBe("DIV");
            Object.keys(expectedStyle).forEach(function (k) {
                expect(style[k], "Property ".concat(k)).toBe(expectedStyle[k]);
            });
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " with id applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test" }))).container;
            sut = container.querySelector("#test");
            expect(sut.id).toBe("test");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " with class applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", className: "custom-class" }))).container;
            sut = container.querySelector("#test .spaces-space-inner");
            expect(sut.className).toBe("spaces-space-inner custom-class");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " with class change applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var _a, container, rerender, sut;
        return __generator(this, function (_b) {
            _a = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", className: "custom-class" }))), container = _a.container, rerender = _a.rerender;
            sut = container.querySelector("#test .spaces-space-inner");
            // act
            rerender(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", className: "different-custom-class" })));
            //assert
            expect(sut.className).toBe("spaces-space-inner different-custom-class");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " with style applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", style: { backgroundColor: "red" } }))).container;
            sut = container.querySelector("#test .spaces-space-inner");
            style = window.getComputedStyle(sut);
            expect(style.backgroundColor).toBe("red");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " with style change applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var _a, container, rerender, sut, style;
        return __generator(this, function (_b) {
            _a = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", style: { backgroundColor: "red" } }))), container = _a.container, rerender = _a.rerender;
            sut = container.querySelector("#test .spaces-space-inner");
            // act
            rerender(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", style: { backgroundColor: "green" } })));
            style = window.getComputedStyle(sut);
            expect(style.backgroundColor).toBe("green");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " scrollable applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", scrollable: true }))).container;
            sut = container.querySelector("#test .spaces-space-inner");
            style = window.getComputedStyle(sut);
            expect(style.overflow).toBe("auto");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " scrollable change applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var _a, container, rerender, sut, style;
        return __generator(this, function (_b) {
            _a = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", scrollable: false }))), container = _a.container, rerender = _a.rerender;
            sut = container.querySelector("#test .spaces-space-inner");
            // act
            rerender(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", scrollable: true })));
            style = window.getComputedStyle(sut);
            expect(style.overflow).toBe("auto");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " as applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", as: "main" }))).container;
            sut = container.querySelector("#test");
            // assert
            expect(sut.nodeName).toBe("MAIN");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " as change applied"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var _a, container, rerender, sut;
        return __generator(this, function (_b) {
            _a = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test" }))), container = _a.container, rerender = _a.rerender;
            // act
            rerender(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", as: "main" })));
            sut = container.querySelector("#test");
            expect(sut.nodeName).toBe("MAIN");
            return [2 /*return*/];
        });
    }); });
};
export var commonAnchorTests = function (name, component, size, edge, oppositeEdge) {
    test("".concat(name, " stacked has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, sut1, style, style1;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null,
                mutateComponent(component, { id: "test", size: 50, order: 0 }),
                mutateComponent(component, { id: "test1", size: 100, order: 1 }))).container;
            sut = fixUp(container.querySelector("#test"));
            sut1 = fixUp(container.querySelector("#test1"));
            style = window.getComputedStyle(sut);
            style1 = window.getComputedStyle(sut1);
            expect(size(style)).toBe("50px");
            expect(edge(style)).toBe("0px");
            expect(oppositeEdge(style)).toBe("");
            expect(size(style1)).toBe("100px");
            expect(edge(style1)).toBe("calc(0px + 50px)");
            expect(oppositeEdge(style1)).toBe("");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " size changed has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var _a, container, rerender, sut, style;
        return __generator(this, function (_b) {
            _a = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", size: 50 }))), container = _a.container, rerender = _a.rerender;
            sut = container.querySelector("#test");
            // act
            rerender(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", size: 100 })));
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("100px");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " stacked DOM reversed has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, sut1, style, style1;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null,
                mutateComponent(component, { id: "test1", size: 100, order: 1 }),
                mutateComponent(component, { id: "test", size: 50, order: 0 }))).container;
            sut = fixUp(container.querySelector("#test"));
            sut1 = fixUp(container.querySelector("#test1"));
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("50px");
            expect(edge(style)).toBe("0px");
            expect(oppositeEdge(style)).toBe("");
            style1 = window.getComputedStyle(sut1);
            expect(size(style1)).toBe("100px");
            expect(edge(style1)).toBe("calc(0px + 50px)");
            expect(oppositeEdge(style1)).toBe("");
            return [2 /*return*/];
        });
    }); });
};
export var commonResizableTests = function (name, component, size, edge, oppositeEdge, horizontal, negate) {
    test("".concat(name, " after resize has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, resizeHandle, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test" }))).container;
            sut = container.querySelector("#test");
            resizeHandle = container.querySelector(".spaces-resize-handle");
            // act
            drag(resizeHandle, sut, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, horizontal ? (negate ? -100 : 100) : 0, horizontal ? 0 : negate ? -100 : 100);
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("calc(50px + 100px)");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " subsequent resize has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, resizeHandle, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test" }))).container;
            sut = container.querySelector("#test");
            resizeHandle = container.querySelector(".spaces-resize-handle");
            // act
            drag(resizeHandle, sut, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, horizontal ? (negate ? -100 : 100) : 0, horizontal ? 0 : negate ? -100 : 100);
            drag(resizeHandle, sut, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, horizontal ? (negate ? 100 : -100) : 0, horizontal ? 0 : negate ? 100 : -100);
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("50px");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " resize then props size change has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var _a, container, rerender, sut, resizeHandle, style;
        return __generator(this, function (_b) {
            _a = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", size: 50 }))), container = _a.container, rerender = _a.rerender;
            sut = container.querySelector("#test");
            resizeHandle = container.querySelector(".spaces-resize-handle");
            // act
            drag(resizeHandle, sut, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, horizontal ? (negate ? -100 : 100) : 0, horizontal ? 0 : negate ? -100 : 100);
            rerender(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", size: 150 })));
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("150px");
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " resize with maximum size constraint has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, resizeHandle, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", size: 50, maximumSize: 100 }))).container;
            sut = container.querySelector("#test");
            resizeHandle = container.querySelector(".spaces-resize-handle");
            // act (resize 100px)
            drag(resizeHandle, sut, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, horizontal ? (negate ? -100 : 100) : 0, horizontal ? 0 : negate ? -100 : 100);
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("calc(50px + 50px)"); // only 50px resized
            return [2 /*return*/];
        });
    }); });
    test("".concat(name, " resize with minimum size constraint has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var container, sut, resizeHandle, style;
        return __generator(this, function (_a) {
            container = render(React.createElement(ViewPort, null, mutateComponent(component, { id: "test", size: 150, minimumSize: 100 }))).container;
            sut = container.querySelector("#test");
            resizeHandle = container.querySelector(".spaces-resize-handle");
            // act (resize -100px)
            drag(resizeHandle, sut, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, horizontal ? (negate ? 100 : -100) : 0, horizontal ? 0 : negate ? 100 : -100);
            style = window.getComputedStyle(sut);
            expect(size(style)).toBe("calc(150px + -50px)"); // only -50px resized
            return [2 /*return*/];
        });
    }); });
};
export var commonPositionedResizeTests = function (name, size, edge, oppositeEdge, handle, horizontal, negate) {
    var testProps = { id: "test", resizable: [ResizeType.Left, ResizeType.Top, ResizeType.Bottom, ResizeType.Right] };
    [
        { name: "left/top/width/height", props: { left: 100, top: 100, width: 100, height: 100 }, widthHeightSpecified: true },
        { name: "left/top/right/bottom", props: { left: 100, top: 100, right: 100, bottom: 100 }, widthHeightSpecified: false },
    ].forEach(function (testCase) {
        test("".concat(name, " (").concat(testCase.name, ") after resize has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
            var container, resizeHandle, sut, style;
            return __generator(this, function (_a) {
                container = render(React.createElement(ViewPort, null, mutateComponent(React.createElement(Positioned, null), __assign(__assign({}, testProps), testCase.props)))).container;
                resizeHandle = container.querySelector("#test-".concat(handle));
                sut = container.querySelector("#test");
                // act
                drag(resizeHandle, sut, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, horizontal ? (negate ? -100 : 100) : 0, horizontal ? 0 : negate ? -100 : 100);
                style = window.getComputedStyle(sut);
                if (testCase.widthHeightSpecified) {
                    expect(size(style)).toBe("calc(100px + -100px)");
                }
                else {
                    expect(edge(style)).toBe("calc(100px + 100px)");
                }
                return [2 /*return*/];
            });
        }); });
        test("".concat(name, " (").concat(testCase.name, ") subsequent resize has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
            var container, resizeHandle, sut, style;
            return __generator(this, function (_a) {
                container = render(React.createElement(ViewPort, null, mutateComponent(React.createElement(Positioned, null), __assign(__assign({}, testProps), testCase.props)))).container;
                resizeHandle = container.querySelector("#test-".concat(handle));
                sut = container.querySelector("#test");
                // act
                drag(resizeHandle, sut, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, horizontal ? (negate ? -100 : 100) : 0, horizontal ? 0 : negate ? -100 : 100);
                drag(resizeHandle, sut, { width: horizontal ? 150 : 0, height: horizontal ? 0 : 150 }, { width: horizontal ? 50 : 0, height: horizontal ? 0 : 50 }, horizontal ? (negate ? 100 : -100) : 0, horizontal ? 0 : negate ? 100 : -100);
                style = window.getComputedStyle(sut);
                if (testCase.widthHeightSpecified) {
                    expect(size(style)).toBe("100px");
                }
                else {
                    expect(edge(style)).toBe("100px");
                }
                return [2 /*return*/];
            });
        }); });
    });
};
//# sourceMappingURL=Common.js.map