import { __awaiter, __generator } from "tslib";
import * as React from "react";
import { render, cleanup } from "@testing-library/react";
import { Fill } from "../../Fill";
import { Left, Top, Right, Bottom, LeftResizable, TopResizable, RightResizable, BottomResizable } from "../../Anchored";
import "@testing-library/jest-dom/extend-expect";
import { ViewPort } from "../../ViewPort";
import { commonPropsTests, commonPropTypesTest, fixUp } from "../Common";
afterEach(cleanup);
commonPropsTests("Fill", React.createElement(Fill, null), {
    position: "absolute",
    left: "0px",
    top: "0px",
    right: "0px",
    bottom: "0px",
    width: "",
    height: "",
});
test("Fill with Left has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Left, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("calc(0px + 10px)");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked Left has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Left, { size: 10, order: 0 }),
            React.createElement(Left, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("calc(0px + 10px + 20px)");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with Top has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Top, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("calc(0px + 10px)");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked Top has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Top, { size: 10, order: 0 }),
            React.createElement(Top, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("calc(0px + 10px + 20px)");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with Right has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Right, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("calc(0px + 10px)");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked Right has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Right, { size: 10, order: 0 }),
            React.createElement(Right, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("calc(0px + 10px + 20px)");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with Bottom has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Bottom, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("calc(0px + 10px)");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked Bottom has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(Bottom, { size: 10, order: 0 }),
            React.createElement(Bottom, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = container.querySelector("#test");
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("calc(0px + 10px + 20px)");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with LeftResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(LeftResizable, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("calc(0px + 10px)");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked LeftResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(LeftResizable, { size: 10, order: 0 }),
            React.createElement(LeftResizable, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("calc(0px + 10px + 20px)");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with TopResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(TopResizable, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("calc(0px + 10px)");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked TopResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(TopResizable, { size: 10, order: 0 }),
            React.createElement(TopResizable, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("calc(0px + 10px + 20px)");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with RightResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(RightResizable, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("calc(0px + 10px)");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked RightResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(RightResizable, { size: 10, order: 0 }),
            React.createElement(RightResizable, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("calc(0px + 10px + 20px)");
        expect(style.bottom).toBe("0px");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with BottomResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(BottomResizable, { size: 10 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("calc(0px + 10px)");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
test("Fill with stacked BottomResizable has correct styles", function () { return __awaiter(void 0, void 0, void 0, function () {
    var container, sut, style;
    return __generator(this, function (_a) {
        container = render(React.createElement(ViewPort, null,
            React.createElement(BottomResizable, { size: 10, order: 0 }),
            React.createElement(BottomResizable, { size: 20, order: 1 }),
            React.createElement(Fill, { id: "test" }))).container;
        sut = fixUp(container.querySelector("#test"));
        style = window.getComputedStyle(sut);
        expect(style.display).toBe("block");
        expect(style.position).toBe("absolute");
        expect(style.left).toBe("0px");
        expect(style.top).toBe("0px");
        expect(style.right).toBe("0px");
        expect(style.bottom).toBe("calc(0px + 10px + 20px)");
        expect(style.width).toBe("");
        expect(style.height).toBe("");
        expect(sut.nodeName).toBe("DIV");
        return [2 /*return*/];
    });
}); });
commonPropTypesTest("Fill", Fill);
//# sourceMappingURL=Fill.js.map