import { __assign, __awaiter, __generator } from "tslib";
import * as React from "react";
import { cleanup, render } from "@testing-library/react";
import { Positioned } from "../../Positioned";
import "@testing-library/jest-dom/extend-expect";
import { commonPositionedResizeTests, commonPropsTests, commonPropTypesTest, hasProps, mutateComponent } from "../Common";
import { useCurrentSpace } from "../../../core-react";
import { ViewPort } from "../../ViewPort";
import { drag } from "../TestUtils";
afterEach(cleanup);
var positionedLeftTopRightBottom = React.createElement(Positioned, { left: 100, top: 100, right: 100, bottom: 100 });
var positionedLeftTopWidthHeight = React.createElement(Positioned, { left: 100, top: 100, width: 100, height: 100 });
commonPropsTests("Positioned (left/top/right/bottom)", positionedLeftTopRightBottom, {
    position: "absolute",
    left: "100px",
    top: "100px",
    right: "100px",
    bottom: "100px",
    width: "",
    height: "",
});
commonPropsTests("Positioned (left/top/width/height)", positionedLeftTopWidthHeight, {
    position: "absolute",
    left: "100px",
    top: "100px",
    right: "",
    bottom: "",
    width: "100px",
    height: "100px",
});
commonPositionedResizeTests("Positioned left resize", 
/* size */ function (style) { return style.width; }, 
/* edge */ function (style) { return style.left; }, 
/* opposite edge */ function (style) { return style.right; }, "ml", 
/* horizontal */ true, 
/* negate */ false);
commonPositionedResizeTests("Positioned right resize", 
/* size */ function (style) { return style.width; }, 
/* edge */ function (style) { return style.right; }, 
/* opposite edge */ function (style) { return style.left; }, "mr", 
/* horizontal */ true, 
/* negate */ true);
commonPositionedResizeTests("Positioned top resize", 
/* size */ function (style) { return style.height; }, 
/* edge */ function (style) { return style.top; }, 
/* opposite edge */ function (style) { return style.bottom; }, "mt", 
/* horizontal */ false, 
/* negate */ false);
commonPositionedResizeTests("Positioned bottom resize", 
/* size */ function (style) { return style.height; }, 
/* edge */ function (style) { return style.bottom; }, 
/* opposite edge */ function (style) { return style.top; }, "mb", 
/* horizontal */ false, 
/* negate */ true);
var testProps = { id: "test" };
[
    { name: "left/top/width/height", props: { left: 100, top: 100, width: 100, height: 100 }, widthHeightSpecified: true },
    { name: "left/top/right/bottom", props: { left: 100, top: 100, right: 100, bottom: 100 }, widthHeightSpecified: false },
].forEach(function (testCase) {
    test("Positioned (".concat(testCase.name, ") after drag has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var Inner, container, sut, dragHandle, style;
        return __generator(this, function (_a) {
            Inner = function () {
                var space = useCurrentSpace();
                return (React.createElement("button", { id: "test-drag-handle", onMouseDown: space.startMouseDrag, onTouchStart: space.startTouchDrag }, "Drag handle"));
            };
            container = render(React.createElement(ViewPort, null, mutateComponent(React.createElement(Positioned, null,
                React.createElement(Inner, null)), __assign(__assign({}, testProps), testCase.props)))).container;
            sut = container.querySelector("#test");
            dragHandle = container.querySelector("#test-drag-handle");
            // act
            drag(dragHandle, sut, 
            /* start rect */ { width: 50, height: 50 }, 
            /* end rect */ { width: 150, height: 150 }, 
            /* end X */ 100, 
            /* end Y */ 100);
            style = window.getComputedStyle(sut);
            if (testCase.widthHeightSpecified) {
                expect(style.width).toBe("100px");
                expect(style.height).toBe("100px");
            }
            else {
                expect(style.left).toBe("calc(100px + 100px)");
                expect(style.right).toBe("calc(100px + -100px)");
                expect(style.top).toBe("calc(100px + 100px)");
                expect(style.bottom).toBe("calc(100px + -100px)");
            }
            return [2 /*return*/];
        });
    }); });
    test("Positioned (".concat(testCase.name, ") after subsequent drag has correct styles"), function () { return __awaiter(void 0, void 0, void 0, function () {
        var Inner, container, sut, dragHandle, style;
        return __generator(this, function (_a) {
            Inner = function () {
                var space = useCurrentSpace();
                return (React.createElement("button", { id: "test-drag-handle", onMouseDown: space.startMouseDrag, onTouchStart: space.startTouchDrag }, "Drag handle"));
            };
            container = render(React.createElement(ViewPort, null, mutateComponent(React.createElement(Positioned, null,
                React.createElement(Inner, null)), __assign(__assign({}, testProps), testCase.props)))).container;
            sut = container.querySelector("#test");
            dragHandle = container.querySelector("#test-drag-handle");
            // act
            drag(dragHandle, sut, 
            /* start rect */ { width: 50, height: 50 }, 
            /* end rect */ { width: 150, height: 150 }, 
            /* end X */ 100, 
            /* end Y */ 100);
            drag(dragHandle, sut, 
            /* start rect */ { width: 150, height: 150 }, 
            /* end rect */ { width: 50, height: 50 }, 
            /* end X */ -100, 
            /* end Y */ -100);
            style = window.getComputedStyle(sut);
            if (testCase.widthHeightSpecified) {
                expect(style.width).toBe("100px");
                expect(style.height).toBe("100px");
            }
            else {
                expect(style.left).toBe("calc(100px + 0px)");
                expect(style.right).toBe("calc(100px + 0px)");
                expect(style.top).toBe("calc(100px + 0px)");
                expect(style.bottom).toBe("calc(100px + 0px)");
            }
            return [2 /*return*/];
        });
    }); });
});
commonPropTypesTest("Positioned", Positioned);
test("Positioned has correct prop types", function () { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        hasProps("Positioned", Positioned, ["left", "top", "right", "bottom", "width", "height", "resizable"]);
        return [2 /*return*/];
    });
}); });
//# sourceMappingURL=Positioned.js.map