import { __assign } from "tslib";
import { throttle } from "./core-utils";
export function createDrag(store) {
    function onMove(space, originalX, originalY, x, y) {
        var adjustmentX = -(originalX - x);
        var adjustmentY = -(originalY - y);
        space.left.adjusted = [adjustmentX];
        space.top.adjusted = [adjustmentY];
        if (space.right.size) {
            space.right.adjusted = [-adjustmentX];
        }
        if (space.bottom.size) {
            space.bottom.adjusted = [-adjustmentY];
        }
        store.updateStyles(space);
    }
    return {
        startDrag: function (e, space, endEvent, moveEvent, getCoords, onDragEnd) {
            if (space.element) {
                var coords = getCoords(e);
                var adjustedLeft = space.left.adjusted.length === 0 ? 0 : space.left.adjusted[0];
                var adjustedTop = space.top.adjusted.length === 0 ? 0 : space.top.adjusted[0];
                var originalMouseX_1 = coords.x - adjustedLeft;
                var originalMouseY_1 = coords.y - adjustedTop;
                var lastX_1 = 0;
                var lastY_1 = 0;
                var moved_1 = false;
                var mouseMove_1 = function (x, y) { return onMove(space, originalMouseX_1, originalMouseY_1, x, y); };
                var throttledMouseMove_1 = throttle(mouseMove_1, 5);
                var withPreventDefault_1 = function (e) {
                    moved_1 = true;
                    var newCoords = getCoords(e);
                    lastX_1 = newCoords.x;
                    lastY_1 = newCoords.y;
                    e.preventDefault();
                    throttledMouseMove_1(lastX_1, lastY_1);
                };
                var removeListener_1 = function () {
                    var _a;
                    if (moved_1) {
                        mouseMove_1(lastX_1, lastY_1);
                    }
                    window.removeEventListener(moveEvent, withPreventDefault_1);
                    window.removeEventListener(endEvent, removeListener_1);
                    if (onDragEnd) {
                        var parentInfo = (space.parentId && ((_a = store.getSpace(space.parentId)) === null || _a === void 0 ? void 0 : _a.element.getBoundingClientRect())) || {
                            left: 0,
                            top: 0,
                            right: 0,
                            bottom: 0,
                            width: 0,
                            height: 0,
                        };
                        var info = (function (_a) {
                            var left = _a.left, top = _a.top, right = _a.right, bottom = _a.bottom, width = _a.width, height = _a.height;
                            return ({ left: left, top: top, right: right, bottom: bottom, width: width, height: height });
                        })(space.element.getBoundingClientRect());
                        onDragEnd(__assign(__assign({}, info), {
                            left: info.left - parentInfo.left,
                            top: info.top - parentInfo.top,
                        }), moved_1);
                    }
                };
                window.addEventListener(moveEvent, withPreventDefault_1);
                window.addEventListener(endEvent, removeListener_1);
            }
        },
    };
}
//# sourceMappingURL=core-dragging.js.map