import { __assign } from "tslib";
import * as React from "react";
import { createStore } from "./core";
import { ResizeType, CenterType, } from "./core-types";
import { coalesce, shortuuid } from "./core-utils";
import { ResizeSensor } from "css-element-queries";
import * as PropTypes from "prop-types";
import { useEffect, useRef, useState } from "react";
// WORKAROUND for React18 strict mode
// https://blog.ag-grid.com/avoiding-react-18-double-mount/
export var useEffectOnce = function (effect) {
    var destroyFunc = useRef();
    var effectCalled = useRef(false);
    var renderAfterCalled = useRef(false);
    var _a = useState(0), _val = _a[0], setVal = _a[1];
    if (effectCalled.current) {
        renderAfterCalled.current = true;
    }
    useEffect(function () {
        // only execute the effect first time around
        if (!effectCalled.current) {
            destroyFunc.current = effect();
            effectCalled.current = true;
        }
        // this forces one render after the effect is run
        setVal(function (val) { return val + 1; });
        return function () {
            // if the comp didn't render since the useEffect was called,
            // we know it's the dummy React cycle
            if (!renderAfterCalled.current) {
                return;
            }
            if (destroyFunc.current) {
                destroyFunc.current();
            }
        };
    }, []);
};
export var ParentContext = React.createContext(undefined);
export var DOMRectContext = React.createContext(undefined);
export var LayerContext = React.createContext(undefined);
export var OptionsContext = React.createContext({});
export var currentStore = createStore();
export var commonProps = {
    id: PropTypes.string,
    className: PropTypes.string,
    style: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
    as: PropTypes.any,
    centerContent: PropTypes.oneOf([CenterType.None, CenterType.Vertical, CenterType.HorizontalVertical]),
    zIndex: PropTypes.number,
    scrollable: PropTypes.bool,
    trackSize: PropTypes.bool,
    allowOverflow: PropTypes.bool,
    handleRender: PropTypes.func,
    onClick: PropTypes.func,
    onDoubleClick: PropTypes.func,
    onMouseDown: PropTypes.func,
    onMouseEnter: PropTypes.func,
    onMouseLeave: PropTypes.func,
    onMouseMove: PropTypes.func,
    onTouchStart: PropTypes.func,
    onTouchMove: PropTypes.func,
    onTouchEnd: PropTypes.func,
};
export function useForceUpdate() {
    var _a = React.useState(0), setTick = _a[1];
    return React.useCallback(function () {
        setTick(function (tick) { return tick + 1; });
    }, []);
}
export function useSpace(props) {
    var store = currentStore;
    var update = useForceUpdate();
    var parent = React.useContext(ParentContext);
    var layer = React.useContext(LayerContext);
    var debug = React.useContext(OptionsContext).debug;
    var spaceId = React.useState(props.id || "s".concat(shortuuid()))[0];
    var elementRef = React.useRef();
    var resizeSensor = React.useRef();
    var _a = React.useState(), domRect = _a[0], setDomRect = _a[1];
    var space = store.getSpace(spaceId);
    if (debug) {
        console.table(store.getSpaces());
    }
    var parsedProps = __assign(__assign({}, props), {
        id: spaceId,
        zIndex: coalesce(props.zIndex, layer),
    });
    if (!space) {
        space = store.createSpace(parent, parsedProps, update);
        store.addSpace(space);
    }
    else {
        store.updateSpace(space, parsedProps);
    }
    var resizeHandles = useSpaceResizeHandles(store, space);
    useEffectOnce(function () {
        var rect = elementRef.current ? elementRef.current.getBoundingClientRect() : new DOMRect();
        space.dimension = __assign(__assign({}, rect), {
            left: Math.floor(rect.left),
            top: Math.floor(rect.top),
            right: Math.floor(rect.right),
            bottom: Math.floor(rect.bottom),
            width: Math.floor(rect.width),
            height: Math.floor(rect.height),
            x: Math.floor(rect.x),
            y: Math.floor(rect.y),
        });
        setDomRect(space.dimension);
        if (props.trackSize) {
            resizeSensor.current = new ResizeSensor(elementRef.current, function (size) {
                space.dimension = __assign(__assign({}, rect), {
                    width: Math.floor(size.width),
                    height: Math.floor(size.height),
                });
                setDomRect(space.dimension);
            });
        }
        return function () {
            resizeSensor.current && resizeSensor.current.detach();
            store.removeSpace(space);
        };
    });
    return { space: space, resizeHandles: resizeHandles, domRect: domRect, elementRef: elementRef };
}
export function useSpaceResizeHandles(store, space) {
    var mouseHandles = [];
    if (space.canResizeLeft) {
        mouseHandles.push({
            id: "".concat(space.id, "-ml"),
            key: "left",
            className: "spaces-resize-handle resize-left",
            onMouseDown: function (event) { return store.startMouseResize(ResizeType.Left, space, event); },
            onTouchStart: function (event) { return store.startTouchResize(ResizeType.Left, space, event); },
        });
    }
    if (space.canResizeRight) {
        mouseHandles.push({
            id: "".concat(space.id, "-mr"),
            key: "right",
            className: "spaces-resize-handle resize-right",
            onMouseDown: function (event) { return store.startMouseResize(ResizeType.Right, space, event); },
            onTouchStart: function (event) { return store.startTouchResize(ResizeType.Right, space, event); },
        });
    }
    if (space.canResizeTop) {
        mouseHandles.push({
            id: "".concat(space.id, "-mt"),
            key: "top",
            className: "spaces-resize-handle resize-top",
            onMouseDown: function (event) { return store.startMouseResize(ResizeType.Top, space, event); },
            onTouchStart: function (event) { return store.startTouchResize(ResizeType.Top, space, event); },
        });
    }
    if (space.canResizeBottom) {
        mouseHandles.push({
            id: "".concat(space.id, "-mb"),
            key: "bottom",
            className: "spaces-resize-handle resize-bottom",
            onMouseDown: function (event) { return store.startMouseResize(ResizeType.Bottom, space, event); },
            onTouchStart: function (event) { return store.startTouchResize(ResizeType.Bottom, space, event); },
        });
    }
    return {
        mouseHandles: mouseHandles,
    };
}
export function useCurrentSpace() {
    var store = currentStore;
    var spaceId = React.useContext(ParentContext);
    var space = spaceId ? store.getSpace(spaceId) : undefined;
    var domRect = React.useContext(DOMRectContext);
    var layer = React.useContext(LayerContext);
    var onMouseDrag = React.useCallback(function (e, onDragEnd) { return (space ? store.startMouseDrag(space, e, onDragEnd) : null); }, [spaceId]);
    var onTouchDrag = React.useCallback(function (e, onDragEnd) { return (space ? store.startTouchDrag(space, e, onDragEnd) : null); }, [spaceId]);
    var onForceUpdate = React.useCallback(function () { return (space ? store.updateStyles(space) : null); }, [spaceId]);
    var defaults = { width: 0, height: 0, x: 0, y: 0 };
    var size = __assign(__assign({}, defaults), domRect);
    return {
        size: size,
        layer: layer || 0,
        startMouseDrag: onMouseDrag,
        startTouchDrag: onTouchDrag,
        forceUpdate: onForceUpdate,
    };
}
//# sourceMappingURL=core-react.js.map