import { ResizeType, Type } from "./core-types";
import { coalesce, throttle } from "./core-utils";
var RESIZE_THROTTLE = 0;
function isHorizontal(resizeType) {
    return resizeType === ResizeType.Left || resizeType === ResizeType.Right;
}
function createAdjuster(resizeType, space, originalX, originalY) {
    var dimensionToAdjust = (function () {
        if (resizeType === ResizeType.Left) {
            return space.left;
        }
        else if (resizeType === ResizeType.Right) {
            return space.right;
        }
        else if (resizeType === ResizeType.Bottom) {
            return space.bottom;
        }
        else if (resizeType === ResizeType.Top) {
            return space.top;
        }
        else {
            throw new Error("unknown resize type");
        }
    })();
    var negater = resizeType === ResizeType.Right || resizeType === ResizeType.Bottom ? function (val) { return -val; } : function (val) { return val; };
    var candidateOppositeDimensionToAdjust = isHorizontal(resizeType) ? space.width : space.height;
    var offset1 = dimensionToAdjust.resized;
    var offset2 = candidateOppositeDimensionToAdjust.resized;
    var rect = space.element.getBoundingClientRect();
    var size = isHorizontal(resizeType) ? rect.width : rect.height;
    var minimumAdjust = coalesce(space.minimumSize, 20) - size + 0;
    var maximumAdjust = space.maximumSize ? space.maximumSize - size + 0 : undefined;
    return function (currentX, currentY) {
        var adjustment = (isHorizontal(resizeType) ? originalX : originalY) - (isHorizontal(resizeType) ? currentX : currentY);
        var dimensionResized = negater(adjustment);
        if (space.type !== Type.Positioned) {
            dimensionResized = Math.max(negater(adjustment), minimumAdjust);
            if (dimensionResized < minimumAdjust) {
                dimensionResized = minimumAdjust;
            }
            if (typeof maximumAdjust === "number") {
                if (dimensionResized > maximumAdjust) {
                    dimensionResized = maximumAdjust;
                }
            }
        }
        if (dimensionToAdjust.size !== undefined) {
            dimensionToAdjust.resized = negater(-adjustment) + offset1;
            if (candidateOppositeDimensionToAdjust.size) {
                candidateOppositeDimensionToAdjust.resized = negater(adjustment) + offset2;
            }
        }
        else {
            candidateOppositeDimensionToAdjust.resized = dimensionResized + offset2;
        }
    };
}
export function createResize(store) {
    return {
        startResize: function (e, resizeType, space, endEvent, moveEvent, getCoords, onResizeEnd) {
            if (space.onResizeStart) {
                var result = space.onResizeStart(resizeType);
                if (typeof result === "boolean" && !result) {
                    return;
                }
            }
            var originalCoords = getCoords(e);
            var adjuster = createAdjuster(resizeType, space, originalCoords.x, originalCoords.y);
            space.resizing = true;
            space.updateParent();
            var lastX = 0;
            var lastY = 0;
            var moved = false;
            var resize = function (currentX, currentY) {
                adjuster(currentX, currentY);
                store.updateStyles(space);
            };
            var withPreventDefault = function (e) {
                moved = true;
                var newCoords = getCoords(e);
                lastX = newCoords.x;
                lastY = newCoords.y;
                e.preventDefault();
                throttle(function (x, y) { return window.requestAnimationFrame(function () { return resize(x, y); }); }, RESIZE_THROTTLE)(lastX, lastY);
            };
            var removeListener = function () {
                if (moved) {
                    resize(lastX, lastY);
                }
                window.removeEventListener(moveEvent, withPreventDefault);
                window.removeEventListener(endEvent, removeListener);
                space.resizing = false;
                space.updateParent();
                var resizeEnd = onResizeEnd || space.onResizeEnd;
                if (resizeEnd) {
                    var currentRect = space.element.getBoundingClientRect();
                    resizeEnd(Math.floor(isHorizontal(resizeType) ? currentRect.width : currentRect.height), currentRect, resizeType);
                }
            };
            window.addEventListener(moveEvent, withPreventDefault);
            window.addEventListener(endEvent, removeListener);
        },
    };
}
//# sourceMappingURL=core-resizing.js.map