import { ResizeHandlePlacement, Type } from "./core-types";
export function omit(object) {
    var keys = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        keys[_i - 1] = arguments[_i];
    }
    var keySet = Object.create(null);
    keys.forEach(function (key) {
        keySet[key] = true;
    });
    var result = Object.create(null);
    Object.keys(object).forEach(function (key) {
        if (!keySet[key]) {
            result[key] = object[key];
        }
    });
    return result;
}
export function shortuuid() {
    var firstPart = (Math.random() * 46656) | 0;
    var secondPart = (Math.random() * 46656) | 0;
    return ("000" + firstPart.toString(36)).slice(-3) + ("000" + secondPart.toString(36)).slice(-3);
}
export function getSizeString(size) {
    return typeof size === "string" ? size : "".concat(size, "px");
}
export function css(size, dontAddCalc) {
    if (size.size === 0 && size.adjusted.length === 0 && size.resized === 0) {
        return "0px";
    }
    var parts = [];
    if (size.size !== undefined) {
        parts.push(getSizeString(size.size));
    }
    size.adjusted.forEach(function (l) { return parts.push(getSizeString(l)); });
    if (size.resized !== 0) {
        parts.push(getSizeString(size.resized));
    }
    if (parts.length === 0) {
        return undefined;
    }
    if (parts.length === 1) {
        return parts[0];
    }
    if (dontAddCalc) {
        return parts.join(" + ");
    }
    return "calc(".concat(parts.join(" + "), ")");
}
export function coalesce() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return args.find(function (x) { return x !== null && x !== undefined; });
}
export function adjustmentsEqual(item1, item2) {
    if (item1.length !== item2.length) {
        return false;
    }
    for (var i = 0, len = item1.length; i < len; i++) {
        if (item1[i] !== item2[i]) {
            return false;
        }
    }
    return true;
}
export function throttle(callback, limit) {
    var wait = false; // Initially, we're not waiting
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        // We return a throttled function
        if (!wait) {
            // If we're not waiting
            callback.apply(void 0, args); // Execute users function
            wait = true; // Prevent future invocations
            setTimeout(function () {
                // After a period of time
                wait = false; // And allow future invocations
            }, limit);
        }
    };
}
export function styleDefinition(space) {
    var cssElements = [];
    var style = {
        position: space.position,
        left: css(space.left),
        top: css(space.top),
        right: css(space.right),
        bottom: css(space.bottom),
        width: css(space.width),
        height: css(space.height),
        zIndex: space.zIndex,
    };
    var cssString = [];
    if (style.position) {
        cssString.push("position: ".concat(style.position, ";"));
    }
    if (style.left) {
        cssString.push("left: ".concat(style.left, ";"));
    }
    if (style.top) {
        cssString.push("top: ".concat(style.top, ";"));
    }
    if (style.right) {
        cssString.push("right: ".concat(style.right, ";"));
    }
    if (style.bottom) {
        cssString.push("bottom: ".concat(style.bottom, ";"));
    }
    if (style.width) {
        cssString.push("width: ".concat(style.width, ";"));
    }
    if (style.height) {
        cssString.push("height: ".concat(style.height, ";"));
    }
    if (style.zIndex) {
        cssString.push("z-index: ".concat(style.zIndex, ";"));
    }
    if (space.allowOverflow) {
        cssString.push("overflow: visible;");
    }
    if (cssString.length > 0) {
        cssElements.push("#".concat(space.id, " { ").concat(cssString.join(" "), " }"));
    }
    if (space.scrollable) {
        cssElements.push("#".concat(space.id, " > .spaces-space-inner { overflow: auto; touch-action: auto; }"));
    }
    var handleOffset = 0;
    var touchHandleSize = space.touchHandleSize / 2 - space.handleSize / 2;
    switch (space.handlePlacement) {
        case ResizeHandlePlacement.Inside:
        case ResizeHandlePlacement.OverlayInside:
            handleOffset = space.handleSize;
            if (space.type === Type.Positioned) {
                handleOffset = 0;
            }
            break;
        case ResizeHandlePlacement.OverlayBoundary:
            handleOffset = space.handleSize / 2;
            break;
    }
    if (space.type === Type.Positioned) {
        if (space.canResizeLeft) {
            cssElements.push("#".concat(space.id, "-ml { left: calc(").concat(css(space.left, true), " - ").concat(handleOffset, "px); width: ").concat(space.handleSize, "px; top: ").concat(css(space.top), "; bottom: ").concat(css(space.bottom), "; height: ").concat(css(space.height), "; }"));
        }
        if (space.canResizeTop) {
            cssElements.push("#".concat(space.id, "-mt { top: calc(").concat(css(space.top, true), " - ").concat(handleOffset, "px); height: ").concat(space.handleSize, "px; left: ").concat(css(space.left), "; right: ").concat(css(space.right), "; width: ").concat(css(space.width), "; }"));
            cssElements.push("#".concat(space.id, "-mt:after { top: -").concat(touchHandleSize, "px; bottom: -").concat(touchHandleSize, "px; left: ").concat(css(space.left), "; right: ").concat(css(space.right), "; width: ").concat(css(space.width), "; }"));
        }
        if (space.canResizeRight) {
            cssElements.push("#".concat(space.id, "-mr:after { left: -").concat(touchHandleSize, "px; right: -").concat(touchHandleSize, "px; top: 0; bottom: 0; }"));
            if (space.width.size) {
                cssElements.push("#".concat(space.id, "-mr { left: calc(").concat(css(space.left, true), " + ").concat(css(space.width, true), " - ").concat(space.handleSize, "px + ").concat(handleOffset, "px); width: ").concat(space.handleSize, "px; top: ").concat(css(space.top), "; bottom: ").concat(css(space.bottom), "; height: ").concat(css(space.height), "; }"));
            }
            else {
                cssElements.push("#".concat(space.id, "-mr { right: calc(").concat(css(space.right, true), " - ").concat(handleOffset, "px); width: ").concat(space.handleSize, "px; top: ").concat(css(space.top), "; bottom: ").concat(css(space.bottom), "; height: ").concat(css(space.height), "; }"));
            }
            cssElements.push("#".concat(space.id, "-mr:after { left: -").concat(touchHandleSize, "px; right: -").concat(touchHandleSize, "px; top: 0; bottom: 0; }"));
        }
        if (space.canResizeBottom) {
            if (space.height.size) {
                cssElements.push("#".concat(space.id, "-mb { top: calc(").concat(css(space.top, true), " + ").concat(css(space.height, true), " - ").concat(space.handleSize, "px + ").concat(handleOffset, "px); height: ").concat(space.handleSize, "px; left: ").concat(css(space.left), "; right: ").concat(css(space.right), "; width: ").concat(css(space.width), "; }"));
            }
            else {
                cssElements.push("#".concat(space.id, "-mb { bottom: calc(").concat(css(space.bottom, true), " - ").concat(handleOffset, "px); height: ").concat(space.handleSize, "px; left: ").concat(css(space.left), "; right: ").concat(css(space.right), "; width: ").concat(css(space.width), "; }"));
            }
            cssElements.push("#".concat(space.id, "-mb:after { top: -").concat(touchHandleSize, "px; bottom: -").concat(touchHandleSize, "px; left: 0; right: 0; }"));
        }
    }
    else {
        if (space.canResizeLeft) {
            cssElements.push("#".concat(space.id, "-ml { right: calc(").concat(css(space.right, true), " + ").concat(css(space.width, true), " - ").concat(handleOffset, "px); width: ").concat(space.handleSize, "px; }"));
            cssElements.push("#".concat(space.id, "-ml:after { left: -").concat(touchHandleSize, "px; right: -").concat(touchHandleSize, "px; top: 0; bottom: 0; }"));
        }
        if (space.canResizeTop) {
            cssElements.push("#".concat(space.id, "-mt { bottom: calc(").concat(css(space.bottom, true), " + ").concat(css(space.height, true), " - ").concat(handleOffset, "px); height: ").concat(space.handleSize, "px; }"));
            cssElements.push("#".concat(space.id, "-mt:after { top: -").concat(touchHandleSize, "px; bottom: -").concat(touchHandleSize, "px; left: 0; right: 0; }"));
        }
        if (space.canResizeRight) {
            cssElements.push("#".concat(space.id, "-mr { left: calc(").concat(css(space.left, true), " + ").concat(css(space.width, true), " - ").concat(handleOffset, "px); width: ").concat(space.handleSize, "px; }"));
            cssElements.push("#".concat(space.id, "-mr:after { left: -").concat(touchHandleSize, "px; right: -").concat(touchHandleSize, "px; top: 0; bottom: 0; }"));
        }
        if (space.canResizeBottom) {
            cssElements.push("#".concat(space.id, "-mb { top: calc(").concat(css(space.top, true), " + ").concat(css(space.height, true), " - ").concat(handleOffset, "px); height: ").concat(space.handleSize, "px; }"));
            cssElements.push("#".concat(space.id, "-mb:after { top: -").concat(touchHandleSize, "px; bottom: -").concat(touchHandleSize, "px; left: 0; right: 0; }"));
        }
    }
    return cssElements.join(" ");
}
export function updateStyleDefinition(space) {
    var definition = styleDefinition(space);
    var existing = document.getElementById("style_".concat(space.id));
    if (existing) {
        if (existing.innerHTML !== definition) {
            existing.innerHTML = definition;
        }
    }
    else {
        var newStyle = document.createElement("style");
        newStyle.id = "style_".concat(space.id);
        newStyle.innerHTML = definition;
        document.head.appendChild(newStyle);
    }
}
export function removeStyleDefinition(space) {
    var existing = document.getElementById("style_".concat(space.id));
    if (existing) {
        document.head.removeChild(existing);
    }
}
//# sourceMappingURL=core-utils.js.map